@@ -570,6 +570,7 @@ void SipCallMember::acceptInvite( const QString &body, const MimeContentType &bo
 	state = state_Connected;
 	statusdesc = "Connected";
 	statusUpdated( this );
+	call->setCallStatus( SipCall::callInProgress );
 }
 
 void SipCallMember::notAcceptableHere( void )
@@ -632,7 +633,7 @@ void SipCallMember::incomingTransaction( SipTransaction *newtrans )
 		if( state == state_Disconnected ) {
 			state = state_RequestingInvite;
 			statusdesc = "Invitation received";
-			remote->sendResponse( SipStatus( 180 ) );
+			remote->sendResponse( SipStatus( 180 )); 
 		} else {
 			state = state_RequestingReInvite;
 			statusdesc = "Session update requested";
@@ -916,6 +917,7 @@ SipCallMember *SipCall::incomingRequest( SipMessage *message )
 	SipUri incominguri( message->getHeaderData( SipHeader::From ) );
 	QString cseq = message->getHeaderData( SipHeader::CSeq );
 	unsigned int seqnum = cseq.left( cseq.find( " " ) ).toUInt();
+	QString seqmethod = cseq.right( cseq.find( " " ) + 1 );
 	SipTransaction *curtrans;
 	printf( "SipCall: Incoming request\n" );
 
@@ -942,7 +944,8 @@ SipCallMember *SipCall::incomingRequest( SipMessage *message )
 		return 0;
 	}
 	for( curtrans = transactions.first(); curtrans != 0; curtrans = transactions.next() ) {
-		if( ( incominguri == curtrans->getCallMember()->getUri() ) && ( seqnum == curtrans->getSeqNum() ) &&
+		if( ( incominguri == curtrans->getCallMember()->getUri() ) && ( seqnum == curtrans->getSeqNum() ) && 
+		    ( seqmethod == curtrans->getSeqMethod() ) &&
 		    ( curtrans->getDirection() == SipTransaction::RemoteRequest ) ) {
 			curtrans->incomingRequestRetransmission( message );
 			return 0;
@@ -952,6 +955,7 @@ SipCallMember *SipCall::incomingRequest( SipMessage *message )
 	// Find or create a member for this request
 	SipCallMember *member = getMember( incominguri );
 	if ( member == NULL ) {
+          printf("SipCall: Create a new incominguri \n");
 		member = new SipCallMember( this, incominguri );
 		if ( message->getMethod() == Sip::INVITE ) {
 			member->setCallMemberType( SipCallMember::Invite );
