@@ -316,7 +316,7 @@ private:
 	QTimer *timer;
 };
 
-typedef QListIterator<SipCallMember> SipCallMemberIterator;
+typedef QPtrListIterator<SipCallMember> SipCallMemberIterator;
 
 /**
  * @short A class for referencing a speficic SIP call.
@@ -536,7 +536,7 @@ private:
 
 	// For SipClient
 	SipCallMember *incomingMessage( SipMessage *message );
-	QList<SipTransaction> &getTransactionList( void ) { return transactions; }
+	QPtrList<SipTransaction> &getTransactionList( void ) { return transactions; }
 
 	// For SipCallMember
 	void addMember( SipCallMember *newmember );
@@ -548,7 +548,7 @@ private:
 
 };
 
-typedef QListIterator<SipCall> SipCallIterator;
+typedef QPtrListIterator<SipCall> SipCallIterator;
 
 #endif // SIPCALL_H_INCLUDED
 
