@@ -401,7 +401,7 @@ void SipClient::incomingMessage( int socketfd )
 				Sip::setLocalAddress( ip );
 				listener.forcePortNumber( port );
 				setupContactUri();
-				QListIterator<SipRegister> reg = user->getSipRegisterList();
+				QPtrListIterator<SipRegister> reg = user->getSipRegisterList();
 				for( ; reg.current(); ++reg ) {
 					current = reg.current();
 					if( current->getRegisterState() == SipRegister::Connected ||
@@ -411,7 +411,7 @@ void SipClient::incomingMessage( int socketfd )
 					}
 				}
 			} else {
-				QListIterator<SipRegister> reg = user->getSipRegisterList();
+				QPtrListIterator<SipRegister> reg = user->getSipRegisterList();
 				for( ; reg.current(); ++reg ) {
 					current = reg.current();
 					if( current->getAutoRegister() ) {
@@ -1034,6 +1034,9 @@ void SipClient::sendResponse( SipMessage *msg, bool contact )
 			printf( "SipClient: Sending TCP Response\n" );
 			outsocket = new TCPMessageSocket;
 			break;
+		case SipVia::TLS:
+			printf( "SipClient: TLS in top via, not supported (full TLS support not implemented)\n" );
+			break;
 		case SipVia::BadTransport:
 			printf( "SipClient: Bad transport on incoming Via\n" );
 			break;
@@ -1232,6 +1235,9 @@ void SipClient::sendQuickResponse( SipMessage *origmessage, const SipStatus &sta
 			printf( "SipClient: Sending TCP Response\n" );
 			outsocket = new TCPMessageSocket;
 			break;
+		case SipVia::TLS:
+			printf( "SipClient: TLS in top via, not supported (full TLS support not implemented)\n" );
+			break;
 		case SipVia::BadTransport:
 			printf( "SipClient: Bad transport on incoming Via\n" );
 			break;
@@ -1345,7 +1351,7 @@ void SipClient::setCallForwardMessage( const QString &newmessage )
 
 const QString SipClient::getUserAgent( void )
 {
-	return "kphone/4.1.0";
+	return "kphone/4.1.1";
 }
 
 void SipClient::setMaxForwards( int newmax )
