@@ -113,7 +113,8 @@ void findFqdn( void )
 		j++;
 	} else {
 		for ( i = 0; i < if_count; i++ ) {
-			if ( strcmp( netconf.ifc_req[i].ifr_name, "lo" ) != 0 ) {
+			if ( strcmp( netconf.ifc_req[i].ifr_name, "lo" ) != 0 
+					&& strncmp( netconf.ifc_req[i].ifr_name, "vmnet", 5) != 0) {
 				strncpy( if_name[j], netconf.ifc_req[i].ifr_name, 20 );
 				strncpy( if_addr[j], inet_ntoa(((struct sockaddr_in*)(&netconf.ifc_req[i].ifr_addr))->sin_addr), 20 );
 				j++;
@@ -194,3 +195,9 @@ char *SipUtil::getLocalFqdn( void )
 	}
 	return dissipate_our_fqdn;
 }
+
+void SipUtil::setLocalFqdn( const char *s )
+{
+	dissipate_our_fqdn = (char *) malloc(strlen(s) + 2);
+	strcpy(dissipate_our_fqdn, s);
+}
