@@ -45,7 +45,7 @@ CallAudio::CallAudio(  KPhoneView *phoneview )
 	local.setIpAddress( "0.0.0.0" );
 	QSettings settings;
 	payload = settings.readNumEntry( "/kphone/dsp/SizeOfPayload", 160 );
-	codec = codecILBC;
+	codec = codecILBC_20;
 	rtpCodec = codecUnknown;
 	videoCodec = codecUnknown;
 	videoRtpCodec = codecUnknown;
@@ -316,21 +316,6 @@ SdpMessage CallAudio::audioOut( void )
 		local.setVideoPort( inrtp->getVideoPortNum() );
 		DspOutAlsa *outalsa = new DspOutAlsa();
 		QSettings settings;
-/*
-		if( settings.readEntry( "/kphone/audio/mode", "readwrite" ) == "readwrite" ) {
-			printf( "CallAudio: Opening ALSA device %s for Input and Output\n", ossfilename.latin1() );
-//			if( !outalsa->openDevice( DspOut::ReadWrite ) ) {
-//				printf( "** audioOut: openDevice Failed.\n" );
-//			} else {
-//				audio_fd = outalsa->audio_fd;
-//			}
-		} else {
-			printf( "CallAudio: Opening OSS device %s for Output\n", ossfilename.latin1() );
-			if( !outalsa->openDevice( DspOut::WriteOnly )){
-				printf( "** audioOut: openDevice Failed.\n" );
-			}
-		}
-*/
 		printf( "CallAudio: Opening ALSA device for Output\n" );
 		if( !outalsa->openDevice( DspOut::WriteOnly )){
 			printf( "** audioOut: openDevice Failed.\n" );
@@ -417,13 +402,17 @@ void CallAudio::readAudioSettings( void )
 	QString audiomodestr = settings.readEntry( "/kphone/audio/audio", "oss" );
 	setAudiomode( audiomodestr );
 
-	QString codec = settings.readEntry( "/kphone/audio/Codec", "ULAW" );
-	if( codec == "ULAW" ) {
-		setCodec( codecULAW );
+	QString codec = settings.readEntry( "/kphone/audio/Codec", "PCMU" );
+	if( codec == "PCMU" ) {
+		setCodec( codecPCMU );
 	} else if( codec == "GSM" ) {
 		setCodec( codecGSM );
+	} else if( codec == "PCMA" ) {
+		setCodec( codecPCMA );
+	} else if( codec == "ILBC_20" ) {
+		setCodec( codecILBC_20 );
 	} else if( codec == "ILBC" ) {
-		setCodec( codecILBC );
+		setCodec( codecILBC_30 );
 	}
 }
 
@@ -497,6 +486,8 @@ bool CallAudio::checkCodec( SipCallMember *member )
 		m = m.left( m.find( "\n" ) );
 		m = m.mid( m.find( "RTP/AVP" ) + 7 );
 		m += ' ';
+
+		// dynamic port 96-127 
 		if( mstr.lower().contains( "ilbc/8000" ) ) {
 			ilbc = mstr.mid( mstr.lower().find( "ilbc/8000" ) - 7, 6 );
 			if( ilbc.contains( ":" ) ) {
@@ -504,22 +495,46 @@ bool CallAudio::checkCodec( SipCallMember *member )
 			}
 			ilbc = ilbc.simplifyWhiteSpace();
 		}
-		int posULAW = m.find( " 0 " );
-		int posGSM = m.find( " 3 " );
+		int posPCMU = m.find( " 0 " );
+		int posGSM  = m.find( " 3 " );
+		int posPCMA = m.find( " 8 " );
 		int posILBC = m.lower().find( " " + ilbc + " " );
-		if( posULAW < 0 ) posULAW = 101;
-		if( posGSM < 0 ) posGSM = 101;
+		if( posPCMU < 0 ) posPCMU = 101;
+		if( posGSM  < 0 ) posGSM  = 101;
+		if( posPCMA < 0 ) posPCMA = 101;
 		if( posILBC < 0 ) posILBC = 101;
-		if( posULAW < posGSM && posULAW < posILBC ) {
-			rtpCodec = codecULAW;
+
+#define MIN(a,b) (a)<(b)?(a):(b)
+		
+		int winner = MIN ( posPCMU , posGSM );
+		    winner = MIN ( winner , posPCMA );
+			winner = MIN ( winner , posILBC );
+ 
+	    if ( winner == posPCMU ) {
+			rtpCodec = codecPCMU;
 			rtpCodecNum = 0;
-		} else if( posGSM < posULAW && posGSM < posILBC ) {
+		}
+		else 
+		if ( winner == posGSM ) {
 			rtpCodec = codecGSM;
 			rtpCodecNum = 3;
-		} else if( posILBC < posULAW && posILBC < posGSM ) {
-			rtpCodec = codecILBC;
-			rtpCodecNum = ilbc.toInt();
 		}
+		if ( winner == posPCMA ) {
+			rtpCodec = codecPCMA;
+			rtpCodecNum = 8;
+		}
+		else 
+		if( winner == posILBC ) {
+			rtpCodec = codecILBC_30;
+			rtpCodecNum = ilbc.toInt();
+			if( mstr.contains( "a=fmtp:" ) ) {
+				QString m = mstr.mid( mstr.find( "a=fmtp:" ) );
+				m = m.left( m.find( "\n" ) );
+				if( m.lower().contains( "mode=20" ) ) {
+					rtpCodec = codecILBC_20;
+				}
+			}
+		} 
 	}
 	if( mstr.contains( "m=video" ) ) {
 		QString ilbc = "";
@@ -550,11 +565,15 @@ bool CallAudio::checkCodec( SipCallMember *member )
 #endif
 	}
 
-	if( rtpCodec == codecILBC ) {
-		printf( "CallAudio: Using iLBC for output\n" );
+	if( rtpCodec == codecILBC_20 ) {
+		printf( "CallAudio: Using iLBC 20ms for output\n" );
+	} else if( rtpCodec == codecILBC_30 ) {
+		printf( "CallAudio: Using iLBC 30ms for output\n" );
+	} else if( rtpCodec == codecPCMA ) {
+		printf( "CallAudio: Using G711a for output\n" );
 	} else if( rtpCodec == codecGSM ) {
 		printf( "CallAudio: Using GSM for output\n" );
-	} else if( rtpCodec == codecULAW ) {
+	} else if( rtpCodec == codecPCMU ) {
 		printf( "CallAudio: Using G711u for output\n" );
 	} else if( rtpCodec == codecUnknown ) {
 		status = false;
@@ -678,10 +697,14 @@ int CallAudio::getRtpCodecNum( void )
 			case codecGSM:
 				c = 3;
 				break;
-			case codecILBC:
+			case codecPCMA:
+				c = 8;
+				break;
+			case codecILBC_20:
+			case codecILBC_30:
 				c = 97;
 				break;
-			case codecULAW:
+			case codecPCMU:
 			default:
 				c = 0;
 				break;
