@@ -17,58 +17,60 @@
 #include "dspoutrtp.h"
 #include "kphone.h"
 
-#define BLOCKL  BLOCKL_30MS
-#define NO_OF_BYTES NO_OF_BYTES_30MS
 
-short ILBCencode( iLBC_Enc_Inst_t *iLBCenc_inst,short *encoded_data, short *data);
-short ILBCdecode( iLBC_Dec_Inst_t *iLBCdec_inst,short *decoded_data, short *encoded_data, short mode);
+short ILBCencode_20( iLBC_Enc_Inst_t *iLBCenc_inst,short *encoded_data, short *data);
+short ILBCdecode_20( iLBC_Dec_Inst_t *iLBCdec_inst,short *decoded_data, short *encoded_data, short mode);
+short ILBCencode_30( iLBC_Enc_Inst_t *iLBCenc_inst,short *encoded_data, short *data);
+short ILBCdecode_30( iLBC_Dec_Inst_t *iLBCdec_inst,short *decoded_data, short *encoded_data, short mode);
 
 
 DspOutRtp::DspOutRtp( const codecType newCodec, int newCodecNum, const QString &hostName, UDPMessageSocket *s )
+	: portnum(0)
+	, curseq(0)
+	, qlen(0)
+	, numunsend(0)
+	, fixedrtplen(160)
+	, deb_frag(0L)
+	, deb_rtp(0L)
+	, ssrc(10)
+	, ref_sec(0)
+	, ref_usec(0)
+	, dsize(4096)
+	, useStun(false)
+	, destroySocket(false)
 {
 	codec = newCodec;
 	codecNum = newCodecNum;
 	if (s) {
 		socket = s;
-		destroySocket = false;
 	} else {
 		socket = new UDPMessageSocket();
 		destroySocket = true;
-	}
-	if (socket == 0) {
-		printf( QObject::tr("DspOutRtp:: Can't create socket") + "\n" );
+		if (socket == 0) {
+			printf( QObject::tr("DspOutRtp:: Can't create socket") + "\n" );
+			abort();
+		}
 	}
 	if( hostName != QString::null && !socket->setHostname( hostName.latin1() ) ) {
 		printf( QObject::tr("DspOutRtp::Hostname lookup failed") + "\n" );
 	}
-	dsize = 4096;  // initial max packet size
-	packetbuf = new unsigned char[ sizeof( rtp_hdr_t ) + dsize ];
-	bufunsend = new unsigned char[ dsize ];
 	if( !( gsmInstEnc = gsm_create() ) ) {
 		printf( "DspOutRtp::GSM_CREATE -error !\n" );
 	}
 	if( !( gsmInstDec = gsm_create() ) ) {
 		printf( "DspOutRtp::GSM_CREATE -error !\n" );
 	}
+	packetbuf = new unsigned char[ sizeof( rtp_hdr_t ) + dsize ];
+	bufunsend = new unsigned char[ dsize ];
 	outbuf = new unsigned char[ dsize ];
 	tmpbuf = new unsigned char[ dsize ];
 	quebuf = new unsigned char[ dsize ];
-	qlen = 0;
-	initEncode(&ilbcEncInst, 30 );
-	initDecode(&ilbcDecInst, 30, 1);
-	numunsend = 0;
-	fixedrtplen = 160;
-	curseq = 0;
-	ts = rand();
-	ssrc = 10;
-	ref_sec = 0;
-	ref_usec = 0;
-	portnum = 0;
+	initEncode(&ilbcEncInst_20, 20 );
+	initDecode(&ilbcDecInst_20, 20, 1);
+	initEncode(&ilbcEncInst_30, 30 );
+	initDecode(&ilbcDecInst_30, 30, 1);
 	audio_buf.resize( dsize * sizeof( short )  );
-	setDeviceName( "rtp" );
-	deb_frag=0L;
-	deb_rtp=0L;
-	useStun = false;
+	setDeviceName("rtp");
 }
 
 DspOutRtp::~DspOutRtp( void )
@@ -124,13 +126,25 @@ bool DspOutRtp::openDevice( DeviceMode mode )
 //------------------------------
 
 	} else {
-		socket->connect( portnum );
-		socket->SetTOS();
-	}
+          if( socket->connect( portnum ) ) {
+            if ( socket->SetTOS() )
+              return false ;  
+          }
+          else 
+            return false;
+        }
 	devstate = DeviceOpened;
 	return true;
 }
 
+#define PCMUCODEC 0
+#define GSMCODEC 3
+#define PCMACODEC 8
+
+typedef struct cb {
+unsigned char (*func)( int frombuf );
+} cb_t;
+
 bool DspOutRtp::writeBuffer( void )
 {
 	short *s;
@@ -151,24 +165,24 @@ bool DspOutRtp::writeBuffer( void )
 		short *frombuf_test;
 		frombuf_test = frombuf;
 		s = (short *)inbuf;
-		for( i=0; i<fromsize; i++) {
+		for( i=0; i<fromsize; ++i) {
 			s[i] = (short)(*frombuf_test);
-			frombuf_test++;
+			++frombuf_test;
 		}
 		tmpsize = writeGSMBuffer( gsmInstEnc, inbuf, outbuf, tmpbuf, quebuf, &qlen, fromsize );
+		h->version = 2;
+		h->p = 0;
+		h->x = 0;
+		h->cc = 0;
+		h->m = 0;
+		h->pt = GSMCODEC;
 		while( tmpsize > 0 ) {
-			h->version = 2;
-			h->p = 0;
-			h->x = 0;
-			h->cc = 0;
-			h->m = 0;
-			h->pt = 3;
-			h->seq = htons( curseq++ );
+			h->seq = htons( ++curseq );
 			h->ts = htonl( ts );
 			ts += GSM_DEC_SAMPLES;
 			h->ssrc = ssrc;
 			databuf = packetbuf + sizeof( rtp_hdr_t );
-			for( int i = 0; i < tmpsize; i++ ) {
+			for( int i = 0; i < tmpsize; ++i ) {
 				databuf[ i ] = outbuf[ i ];
 			}
 			if( socket->send( (char *) packetbuf, sizeof( rtp_hdr_t ) + tmpsize ) < 0 ) {
@@ -177,47 +191,72 @@ bool DspOutRtp::writeBuffer( void )
 			}
 			tmpsize = writeGSMBuffer( gsmInstEnc, inbuf, outbuf, tmpbuf, quebuf, &qlen, 0 );
 		}
-	} else if( codec == codecILBC ) {
+	}
+	else if( codec == codecILBC_20 || codec == codecILBC_30 ) {
 		short *frombuf_test;
 		frombuf_test = frombuf;
 		s = (short *)inbuf;
-		for( i=0; i<fromsize; i++) {
+		for( i=0; i<fromsize; ++i) {
 			s[i] = (short)(*frombuf_test);
-			frombuf_test++;
+			++frombuf_test;
 		}
-		tmpsize = writeILBCBuffer( &ilbcEncInst, inbuf, outbuf, tmpbuf, quebuf, &qlen, fromsize );
+		if( codec == codecILBC_20 ) {
+			tmpsize = writeILBCBuffer_20( &ilbcEncInst_20, inbuf, outbuf, tmpbuf, quebuf, &qlen, fromsize );
+		} else {
+			tmpsize = writeILBCBuffer_30( &ilbcEncInst_30, inbuf, outbuf, tmpbuf, quebuf, &qlen, fromsize );
+		}
+		h->version = 2;
+		h->p = 0;
+		h->x = 0;
+		h->cc = 0;
+		h->m = 0;
+		h->pt = codecNum;
 		while( tmpsize > 0 ) {
-			h->version = 2;
-			h->p = 0;
-			h->x = 0;
-			h->cc = 0;
-			h->m = 0;
-			h->pt = codecNum;
-			h->seq = htons( curseq++ );
+			h->seq = htons( ++curseq );
 			h->ts = htonl( ts );
-			ts += BLOCKL;
+			if( codec == codecILBC_20 ) {
+				ts += BLOCKL_20MS;
+			} else {
+				ts += BLOCKL_30MS;
+			}
 			h->ssrc = ssrc;
 			databuf = packetbuf + sizeof( rtp_hdr_t );
-			for( int i = 0; i < tmpsize; i++ ) {
+			for( int i = 0; i < tmpsize; ++i ) {
 				databuf[ i ] = outbuf[ i ];
 			}
 			if( socket->send( (char *) packetbuf, sizeof( rtp_hdr_t ) + tmpsize ) < 0 ) {
 				printf("DspOutRtp::writeBuffer: %s\n", strerror(errno));
 				return false;
 			}
-			tmpsize = writeILBCBuffer( &ilbcEncInst, inbuf, outbuf, tmpbuf, quebuf, &qlen, 0 );
+			if( codec == codecILBC_20 ) {
+				tmpsize = writeILBCBuffer_20( &ilbcEncInst_20, inbuf, outbuf, tmpbuf, quebuf, &qlen, 0 );
+			} else {
+				tmpsize = writeILBCBuffer_30( &ilbcEncInst_30, inbuf, outbuf, tmpbuf, quebuf, &qlen, 0 );
+			}
 		}
-	} else if( codec == codecULAW ) {
+	}
+	else if( codec == codecPCMA || codec == codecPCMU ) {
+		cb_t callb;
 		wlbuf = bufunsend;
+		h->version = 2;
+		h->p = 0;
+		h->x = 0;
+		h->cc = 0;
+		h->m = 0;
+		switch ( codec ) {
+          case codecPCMU:
+			  h->pt = PCMUCODEC;
+			  callb.func = &linear2ulaw;
+			  break;
+		  case codecPCMA:
+			  h->pt = PCMACODEC;
+			  callb.func = &linear2pcma;
+		  default:
+			  break;
+		}
 		while(bytesnew+numunsend >= fixedrtplen){
-			deb_rtp++;
-			h->version = 2;
-			h->p = 0;
-			h->x = 0;
-			h->cc = 0;
-			h->m = 0;
-			h->pt = 0;
-			h->seq = htons( curseq++ );
+			++deb_rtp;
+			h->seq = htons( ++curseq );
 			h->ts = htonl( ts );
 			ts += fixedrtplen;
 			h->ssrc = ssrc;
@@ -225,36 +264,39 @@ bool DspOutRtp::writeBuffer( void )
 			bytesgot = 0;
 			while( numunsend > 0 ) {
 				*databuf = *wlbuf;
-				databuf++;
-				wlbuf++;
-				numunsend--;
-				bytesgot++;
+				++databuf;
+				++wlbuf;
+				--numunsend;
+				++bytesgot;
 			}
 			wlbuf = bufunsend;
 			while( bytesgot < fixedrtplen ) {
-				*databuf = linear2ulaw( (short) (*frombuf) );
-				databuf++;
-				frombuf++;
-				bytesnew--;
-				bytesgot++;
+				*databuf = callb.func( *frombuf );
+				++databuf;
+				++frombuf;
+				--bytesnew;
+				++bytesgot;
 			}
 			if( socket->send( (char *) packetbuf, sizeof( rtp_hdr_t ) + fixedrtplen ) < 0 ) {
 				printf("DspOutRtp::writeBuffer: %s\n", strerror(errno));
 				return false;
 			}
 		}
-
 		if( bytesnew > 0 ) {
 			wlbuf = bufunsend + numunsend;
 			numunsend += bytesnew;
 			while( bytesnew > 0 ){
-				*wlbuf = linear2ulaw( (short) (*frombuf) );
-				wlbuf++;
-				frombuf++;
-				bytesnew--;
+				*wlbuf = callb.func( *frombuf );
+				++wlbuf;
+				++frombuf;
+				--bytesnew;
 			}
 		}
-		deb_frag++;
+		++deb_frag;
+	}
+	else {
+       printf("DspOutRtp::writeBuffer: unknown Codec %i\n",codec);
+	   return false;
 	}
 
 	return true;
@@ -297,27 +339,47 @@ bool DspOutRtp::readBuffer( int bytes )
 	int size;
 	recvsize = socket->receive( (char *) packetbuf, sizeof( rtp_hdr_t ) + dsize );
 	rtp_hdr_t *h = (rtp_hdr_t *) packetbuf;
-	if( h->pt == 0 ) {
+	if( h->pt == PCMUCODEC ) {
 		audio_buf.resize( ( recvsize - (int) sizeof( rtp_hdr_t ) ) * sizeof( short ) );
 		outbuf = (short *) audio_buf.getData();
 		inbuf = &packetbuf[ sizeof( rtp_hdr_t ) ];
-		for( i = 0; i < recvsize - (int) sizeof( rtp_hdr_t ); i++ ) {
-			*outbuf++ = (short) ulaw2linear( inbuf[ i ] );
+		for( i = 0; i < recvsize - (int) sizeof( rtp_hdr_t ); ++i ) {
+			*outbuf = (short) ulaw2linear( inbuf[ i ] );
+			++outbuf;
 		}
-	} else if( h->pt == 3 ) {
+	} else if( h->pt == GSMCODEC ) {
 		audio_buf.resize( GSM_DEC_SAMPLES * sizeof( short ) );
 		outbuf = (short *) audio_buf.getData();
 		inbuf = &packetbuf[ sizeof( rtp_hdr_t ) ];
 		readGSMBuffer( gsmInstDec, inbuf, tmpbuf, false );
 		short *s = (short *)tmpbuf;
-		for( i = 0; i < GSM_DEC_SAMPLES; i++) {
-			*outbuf++ = (short)(s[i]);
+		for( i = 0; i < GSM_DEC_SAMPLES; ++i) {
+			*outbuf = (short)(s[i]);
+			++outbuf;
 		}
-	} else if( codec == codecILBC && (int)h->pt == codecNum ) {
-		audio_buf.resize( BLOCKL * sizeof( short ) );
+	} else if( h->pt == PCMACODEC ) {
+		audio_buf.resize( ( recvsize - (int) sizeof( rtp_hdr_t ) ) * sizeof( short ) );
 		outbuf = (short *) audio_buf.getData();
 		inbuf = &packetbuf[ sizeof( rtp_hdr_t ) ];
-		size = readILBCBuffer( &ilbcDecInst, inbuf, tmpbuf, 1, false );
+		for( i = 0; i < recvsize - (int) sizeof( rtp_hdr_t ); ++i ) {
+			*outbuf = (short) pcma2linear( inbuf[ i ] );
+			++outbuf;
+		}
+	} else if( codec == codecILBC_20 && (int)h->pt == codecNum ) {
+		audio_buf.resize( BLOCKL_20MS * sizeof( short ) );
+		outbuf = (short *) audio_buf.getData();
+		inbuf = &packetbuf[ sizeof( rtp_hdr_t ) ];
+		size = readILBCBuffer_20( &ilbcDecInst_20, inbuf, tmpbuf, 1, false );
+		short *s = (short *)tmpbuf;
+		for( i = 0; i < size; ++i) {
+			*outbuf = (short)(s[i]);
+			++outbuf;
+		}
+	} else if( codec == codecILBC_30 && (int)h->pt == codecNum ) {
+		audio_buf.resize( BLOCKL_30MS * sizeof( short ) );
+		outbuf = (short *) audio_buf.getData();
+		inbuf = &packetbuf[ sizeof( rtp_hdr_t ) ];
+		size = readILBCBuffer_30( &ilbcDecInst_30, inbuf, tmpbuf, 1, false );
 		short *s = (short *)tmpbuf;
 		for( i = 0; i < size; i++) {
 			*outbuf++ = (short)(s[i]);
@@ -339,7 +401,7 @@ bool DspOutRtp::sendStunRequest( UDPMessageSocket *socketStun )
 		StunRequestSimple req;
 		req.msgHdr.msgType = htons(BindRequestMsg);
 		req.msgHdr.msgLength = htons( sizeof(StunRequestSimple)-sizeof(StunMsgHdr) );
-		for ( int i=0; i<16; i++ ) {
+		for ( int i=0; i<16; ++i ) {
 			req.msgHdr.id.octet[i]=0;
 		}
 		int id = rand();
@@ -433,10 +495,10 @@ int DspOutRtp::writeGSMBuffer( gsm gsmInst,
 		tbuf = (short *)tmp_buf;
 		while( inx < GSM_DEC_SAMPLES ) {
 			*tbuf = *qbuf;
-			tbuf++;
-			qbuf++;
-			inq--;
-			inx++;
+			++tbuf;
+			++qbuf;
+			--inq;
+			++inx;
 		}
 		tbuf = (short *)tmp_buf;
 		gsm_encode( gsmInst, (gsm_signal *)tbuf, (gsm_byte *)obuf);
@@ -446,18 +508,18 @@ int DspOutRtp::writeGSMBuffer( gsm gsmInst,
 		tbuf = (short *)tmp_buf;
 		while( inq > 0 ) {
 			*tbuf = *qbuf;
-			tbuf++;
-			qbuf++;
-			inq--;
-			inx++;
+			++tbuf;
+			++qbuf;
+			--inq;
+			++inx;
 		}
 		*qlen = 0;
 		while( inx < GSM_DEC_SAMPLES ) {
 			*tbuf = *ibuf;
-			tbuf++;
-			ibuf++;
-			size--;
-			inx++;
+			++tbuf;
+			++ibuf;
+			--size;
+			++inx;
 		}
 		tbuf = (short *)tmp_buf;
 		gsm_encode( gsmInst, (gsm_signal *)tbuf, (gsm_byte *)obuf);
@@ -469,10 +531,10 @@ int DspOutRtp::writeGSMBuffer( gsm gsmInst,
 		qbuf = (short *)(queue + ( inq * sizeof(short) ) );
 		while( size > 0 ) {
 			*qbuf = *ibuf;
-			inq++;
-			size--;
-			qbuf++;
-			ibuf++;
+			++inq;
+			--size;
+			++qbuf;
+			++ibuf;
 		}
 		*qlen = inq;
 	}
@@ -496,10 +558,10 @@ int DspOutRtp::readGSMBuffer( gsm Gsm_Inst,
 
 
 /*************************************************************************/
-/* iLBC                                                                   */
+/* iLBC 20ms                                                                  */
 /*************************************************************************/
 
-int DspOutRtp::writeILBCBuffer( iLBC_Enc_Inst_t *Enc_Inst,
+int DspOutRtp::writeILBCBuffer_20( iLBC_Enc_Inst_t *Enc_Inst,
 		unsigned char *input_buf, unsigned char *output_buf,
 		unsigned char *tmp_buf, unsigned char *queue,
 		int *qlen, int size )
@@ -515,47 +577,47 @@ int DspOutRtp::writeILBCBuffer( iLBC_Enc_Inst_t *Enc_Inst,
 	qbuf = (short *)queue;
 	inq = *qlen;
 	inx = 0;
-	if( inq >= BLOCKL ) {
+	if( inq >= BLOCKL_20MS ) {
 		tbuf = (short *)tmp_buf;
-		while( inx < BLOCKL ) {
+		while( inx < BLOCKL_20MS ) {
 			*tbuf = *qbuf;
-			tbuf++;
-			qbuf++;
-			inq--;
-			inx++;
+			++tbuf;
+			++qbuf;
+			--inq;
+			++inx;
 		}
 		tbuf = (short *)tmp_buf;
-		outbufsize = ILBCencode( Enc_Inst, obuf, tbuf);
+		outbufsize = ILBCencode_20( Enc_Inst, obuf, tbuf);
 		*qlen = inq;
-	} else if( inq + size >= BLOCKL ) {
+	} else if( inq + size >= BLOCKL_20MS ) {
 		tbuf = (short *)tmp_buf;
 		while( inq > 0 ) {
 			*tbuf = *qbuf;
-			tbuf++;
-			qbuf++;
-			inq--;
-			inx++;
+			++tbuf;
+			++qbuf;
+			--inq;
+			++inx;
 		}
 		*qlen = 0;
-		while( inx < BLOCKL ) {
+		while( inx < BLOCKL_20MS ) {
 			*tbuf = *ibuf;
-			tbuf++;
-			ibuf++;
-			size--;
-			inx++;
+			++tbuf;
+			++ibuf;
+			--size;
+			++inx;
 		}
 		tbuf = (short *)tmp_buf;
-		outbufsize = ILBCencode( Enc_Inst, obuf, tbuf);
+		outbufsize = ILBCencode_20( Enc_Inst, obuf, tbuf);
 	}
 	if( size > 0 ) {
 		inq = *qlen;
 		qbuf = (short *)(queue + ( inq * sizeof(short) ) );
 		while( size > 0 ) {
 			*qbuf = *ibuf;
-			inq++;
-			size--;
-			qbuf++;
-			ibuf++;
+			++inq;
+			--size;
+			++qbuf;
+			++ibuf;
 		}
 		*qlen = inq;
 	}
@@ -563,7 +625,7 @@ int DspOutRtp::writeILBCBuffer( iLBC_Enc_Inst_t *Enc_Inst,
 }
 
 
-int DspOutRtp::readILBCBuffer( iLBC_Dec_Inst_t *Dec_Inst,
+int DspOutRtp::readILBCBuffer_20( iLBC_Dec_Inst_t *Dec_Inst,
 		unsigned char *input_buf, unsigned char *output_buf,
 		short mode, int ignore)
 {
@@ -572,37 +634,31 @@ int DspOutRtp::readILBCBuffer( iLBC_Dec_Inst_t *Dec_Inst,
 	outbuf = (short *)output_buf;
 	ibuf = (short *)input_buf;
 	if( !ignore ) {
-		return ILBCdecode( Dec_Inst, outbuf, ibuf, mode );
+		return ILBCdecode_20( Dec_Inst, outbuf, ibuf, mode );
 	}
 	return 0;
 }
 
 
-void  DspOutRtp::setStunSrv( QString newStunSrv )
-{
-	useStun = true;
-	stunSrv = newStunSrv;
-}
-
 /*----------------------------------------------------------------*
  *  Encoder interface function
  *---------------------------------------------------------------*/
 
-short ILBCencode( iLBC_Enc_Inst_t *iLBCenc_inst,
+short ILBCencode_20( iLBC_Enc_Inst_t *iLBCenc_inst,
 		short *encoded_data,short *data )
 {
-	float block[BLOCKL];
+	float block[BLOCKL_20MS];
 	int k;
 
 /* convert signal to float */
 
-	for(k=0;k<BLOCKL;k++) block[k] = (float)data[k];
+	for(k=0;k<BLOCKL_20MS;++k) block[k] = (float)data[k];
 
 /* do the actual encoding */
 
 	iLBC_encode((unsigned char *)encoded_data,block,iLBCenc_inst);
 
-	return (short)(NO_OF_BYTES);
+	return (short)(NO_OF_BYTES_20MS);
 }
 
 
@@ -610,11 +666,11 @@ short ILBCencode( iLBC_Enc_Inst_t *iLBCenc_inst,
  *  Decoder interface function
  *---------------------------------------------------------------*/
 
-short ILBCdecode(iLBC_Dec_Inst_t *iLBCdec_inst,
+short ILBCdecode_20(iLBC_Dec_Inst_t *iLBCdec_inst,
 		short *decoded_data, short *encoded_data, short mode)
 {
 	int k;
-	float decblock[BLOCKL], dtmp;
+	float decblock[BLOCKL_20MS], dtmp;
 
 /* check if mode is valid */
 
@@ -630,14 +686,159 @@ short ILBCdecode(iLBC_Dec_Inst_t *iLBCdec_inst,
 
 /* convert to short */
 
-	for(k=0;k<BLOCKL;k++){
+	for(k=0;k<BLOCKL_20MS;++k){
 		dtmp=decblock[k];
 		if (dtmp<MIN_SAMPLE)dtmp=MIN_SAMPLE;
 		else if (dtmp>MAX_SAMPLE)dtmp=MAX_SAMPLE;
 		decoded_data[k] = (short) dtmp;
 	}
 
-	return (short)BLOCKL;
+	return (short)BLOCKL_20MS;
+}
+
+/*************************************************************************/
+/* iLBC 30ms                                                                  */
+/*************************************************************************/
+
+int DspOutRtp::writeILBCBuffer_30( iLBC_Enc_Inst_t *Enc_Inst,
+		unsigned char *input_buf, unsigned char *output_buf,
+		unsigned char *tmp_buf, unsigned char *queue,
+		int *qlen, int size )
+{
+	int outbufsize = 0;
+	int inq, inx;
+	short *ibuf;
+	short *obuf;
+	short *tbuf;
+	short *qbuf;
+	ibuf = (short *)input_buf;
+	obuf = (short *)output_buf;
+	qbuf = (short *)queue;
+	inq = *qlen;
+	inx = 0;
+	if( inq >= BLOCKL_30MS ) {
+		tbuf = (short *)tmp_buf;
+		while( inx < BLOCKL_30MS ) {
+			*tbuf = *qbuf;
+			++tbuf;
+			++qbuf;
+			--inq;
+			++inx;
+		}
+		tbuf = (short *)tmp_buf;
+		outbufsize = ILBCencode_30( Enc_Inst, obuf, tbuf);
+		*qlen = inq;
+	} else if( inq + size >= BLOCKL_30MS ) {
+		tbuf = (short *)tmp_buf;
+		while( inq > 0 ) {
+			*tbuf = *qbuf;
+			++tbuf;
+			++qbuf;
+			--inq;
+			++inx;
+		}
+		*qlen = 0;
+		while( inx < BLOCKL_30MS ) {
+			*tbuf = *ibuf;
+			++tbuf;
+			++ibuf;
+			--size;
+			++inx;
+		}
+		tbuf = (short *)tmp_buf;
+		outbufsize = ILBCencode_30( Enc_Inst, obuf, tbuf);
+	}
+	if( size > 0 ) {
+		inq = *qlen;
+		qbuf = (short *)(queue + ( inq * sizeof(short) ) );
+		while( size > 0 ) {
+			*qbuf = *ibuf;
+			++inq;
+			--size;
+			++qbuf;
+			++ibuf;
+		}
+		*qlen = inq;
+	}
+	return outbufsize;
 }
 
 
+int DspOutRtp::readILBCBuffer_30( iLBC_Dec_Inst_t *Dec_Inst,
+		unsigned char *input_buf, unsigned char *output_buf,
+		short mode, int ignore)
+{
+	short *outbuf;
+	short *ibuf;
+	outbuf = (short *)output_buf;
+	ibuf = (short *)input_buf;
+	if( !ignore ) {
+		return ILBCdecode_30( Dec_Inst, outbuf, ibuf, mode );
+	}
+	return 0;
+}
+
+
+/*----------------------------------------------------------------*
+ *  Encoder interface function
+ *---------------------------------------------------------------*/
+
+short ILBCencode_30( iLBC_Enc_Inst_t *iLBCenc_inst,
+		short *encoded_data,short *data )
+{
+	float block[BLOCKL_30MS];
+	int k;
+
+/* convert signal to float */
+
+	for(k=0;k<BLOCKL_30MS;++k) block[k] = (float)data[k];
+
+/* do the actual encoding */
+
+	iLBC_encode((unsigned char *)encoded_data,block,iLBCenc_inst);
+
+	return (short)(NO_OF_BYTES_30MS);
+}
+
+
+/*----------------------------------------------------------------*
+ *  Decoder interface function
+ *---------------------------------------------------------------*/
+
+short ILBCdecode_30(iLBC_Dec_Inst_t *iLBCdec_inst,
+		short *decoded_data, short *encoded_data, short mode)
+{
+	int k;
+	float decblock[BLOCKL_30MS], dtmp;
+
+/* check if mode is valid */
+
+	if(mode<0 || mode>1){
+		printf( "\nERROR - Wrong mode - 0, 1 allowed\n" );
+		exit(3);
+	}
+
+/* do actual decoding of block */
+
+	iLBC_decode( decblock,
+		(unsigned char *)encoded_data, iLBCdec_inst, mode);
+
+/* convert to short */
+
+	for(k=0;k<BLOCKL_30MS;++k){
+		dtmp=decblock[k];
+		if (dtmp<MIN_SAMPLE)dtmp=MIN_SAMPLE;
+		else if (dtmp>MAX_SAMPLE)dtmp=MAX_SAMPLE;
+		decoded_data[k] = (short) dtmp;
+	}
+
+	return (short)BLOCKL_30MS;
+}
+
+
+
+void  DspOutRtp::setStunSrv( QString newStunSrv )
+{
+	useStun = true;
+	stunSrv = newStunSrv;
+}
