@@ -50,7 +50,7 @@ public:
 	bool sendStunRequest( UDPMessageSocket *socket );
 	unsigned int receiveStunResponse( UDPMessageSocket *socket );
 	void setStunSrv( QString newStunSrv );
-	void setCodec(  const codecType newCodec, int newCodecNum );
+	void setCodec( const codecType newCodec, int newCodecNum );
 
 private:
 	int writeGSMBuffer( gsm Gsm_Inst,
@@ -60,11 +60,18 @@ private:
 	int readGSMBuffer( gsm Gsm_Inst,
 		unsigned char *input_buf, unsigned char *output_buf,
 		int ignore );
-	int writeILBCBuffer( iLBC_Enc_Inst_t *Enc_Inst,
+	int writeILBCBuffer_20( iLBC_Enc_Inst_t *Enc_Inst,
 		unsigned char *input_buf, unsigned char *output_buf,
 		unsigned char *tmp_buf, unsigned char *queue,
 		int *qlen, int size );
-	int readILBCBuffer( iLBC_Dec_Inst_t *Dec_Inst,
+	int readILBCBuffer_20( iLBC_Dec_Inst_t *Dec_Inst,
+		unsigned char *input_buf, unsigned char *output_buf,
+		short mode, int ignore);
+	int writeILBCBuffer_30( iLBC_Enc_Inst_t *Enc_Inst,
+		unsigned char *input_buf, unsigned char *output_buf,
+		unsigned char *tmp_buf, unsigned char *queue,
+		int *qlen, int size );
+	int readILBCBuffer_30( iLBC_Dec_Inst_t *Dec_Inst,
 		unsigned char *input_buf, unsigned char *output_buf,
 		short mode, int ignore);
 
@@ -88,8 +95,10 @@ private:
 	gsm gsmInstEnc;
 	gsm gsmInstDec;
 	int qlen;
-	iLBC_Enc_Inst_t ilbcEncInst;
-	iLBC_Dec_Inst_t ilbcDecInst;
+	iLBC_Enc_Inst_t ilbcEncInst_20;
+	iLBC_Dec_Inst_t ilbcDecInst_20;
+	iLBC_Enc_Inst_t ilbcEncInst_30;
+	iLBC_Dec_Inst_t ilbcDecInst_30;
 
 	size_t numunsend;
 	size_t fixedrtplen;
