@@ -387,21 +387,14 @@ void KPhoneView::contactDoubleClicked( QListViewItem *i )
 		return;
 	}
 	QString subject = ( (ContactsListViewItem *) i )->getCall()->getSubject();
-	SipUri uri = SipUri( buttonSipUri->text() );
-	KInstantMessageWidget *imwidget;
-	for( imwidget = imwList.first(); imwidget != 0; imwidget = imwList.next() ) {
-		if( imwidget->getCall()->getSubject() == uri.uri() &&
-		    imwidget->getRemote() == subject ) {
-			imwidget->show();
-			return;
-		}
-	}
-	SipCall *initcall = new SipCall( user );
-	initcall->setSubject( uri.uri() );
-	imwidget = new KInstantMessageWidget( sipauthentication, initcall, this );
-	imwList.append( imwidget );
-	imwidget->setRemote( subject );
-	imwidget->show();
+	SipCall *newcall = new SipCall( user, QString::null, SipCall::StandardCall );
+	newcall->setSubject( user->getUri().uri() );
+	KCallWidget *widget = new KCallWidget( sipauthentication, callAudio, newcall, this );
+	cwList.append( widget );
+	connect( widget, SIGNAL( redirectCall( const SipUri &, const QString & ) ),
+		this, SLOT( redirectCall( const SipUri &, const QString & ) ) );
+	widget->pleaseDial(subject);
+	widget->show();
 }
 
 void KPhoneView::contactSendMessage()
@@ -454,9 +447,9 @@ void KPhoneView::contactCall()
 	callAudio->readVideoSettings();
 	KCallWidget *widget = new KCallWidget( sipauthentication, callAudio, newcall, this );
 	cwList.append( widget );
-	widget->setRemote( subject );
 	connect( widget, SIGNAL( redirectCall( const SipUri &, const QString & ) ),
 		this, SLOT( redirectCall( const SipUri &, const QString & ) ) );
+	widget->pleaseDial(subject);
 	widget->show();
 }
 
@@ -834,14 +827,14 @@ void KPhoneView::redirectCall( const SipUri &calluri, const QString &subject )
 	widget->show();
 }
 
-void KPhoneView::makeNewCall( void )
+KCallWidget *KPhoneView::DoCall( QString num, SipCall::CallType ctype )
 {
 	updateWidgetList();
 	if( !buttonSipUri->text().compare( tr("Set Identity") ) ){
 		QMessageBox::information( this, tr("KPhone"), tr("Set First Identity.") );
-		return;
+		return NULL;
 	}
-	SipCall *newcall = new SipCall( user, QString::null, SipCall::StandardCall );
+	SipCall *newcall = new SipCall( user, QString::null, ctype );
 	QString subject;
 	subject.sprintf( user->getUri().uri() );
 	newcall->setSubject( subject );
@@ -850,40 +843,27 @@ void KPhoneView::makeNewCall( void )
 	callAudio->readVideoSettings();
 	KCallWidget *widget = new KCallWidget( sipauthentication, callAudio, newcall, this );
 	cwList.append( widget );
-	widget->setRemote( lineeditCall->text() );
-	if( !lineeditCall->text().isEmpty() ) {
+	widget->setRemote( num );
+	if( !num.isEmpty() ) {
 		widget->clickDial();
 	}
-	lineeditCall->setText("");
 	connect( widget, SIGNAL( redirectCall( const SipUri &, const QString & ) ),
 		this, SLOT( redirectCall( const SipUri &, const QString & ) ) );
 	widget->show();
+	
+	return widget;
+}
+
+void KPhoneView::makeNewCall( void )
+{
+	if (DoCall(lineeditCall->text(), SipCall::StandardCall))
+		lineeditCall->setText("");
 }
 
 void KPhoneView::makeVideoCall( void )
 {
-	updateWidgetList();
-	if( !buttonSipUri->text().compare( tr("Set Identity") ) ){
-		QMessageBox::information( this, tr("KPhone"), tr("Set First Identity.") );
-		return;
-	}
-	SipCall *newcall = new SipCall( user, QString::null, SipCall::videoCall );
-	QString subject;
-	subject.sprintf( user->getUri().uri() );
-	newcall->setSubject( subject );
-	callAudio = new CallAudio( this );
-	callAudio->readAudioSettings();
-	callAudio->readVideoSettings();
-	KCallWidget *widget = new KCallWidget( sipauthentication, callAudio, newcall, this );
-	cwList.append( widget );
-	widget->setRemote( lineeditCall->text() );
-	if( !lineeditCall->text().isEmpty() ) {
-		widget->clickDial();
-	}
-	lineeditCall->setText("");
-	connect( widget, SIGNAL( redirectCall( const SipUri &, const QString & ) ),
-		this, SLOT( redirectCall( const SipUri &, const QString & ) ) );
-	widget->show();
+	if (DoCall(lineeditCall->text(), SipCall::videoCall))
+		lineeditCall->setText("");
 }
 
 void KPhoneView::updateIdentity( SipUser *newUser, SipRegister *newReg )
