@@ -37,6 +37,7 @@ KSipAuthenticationRequest::KSipAuthenticationRequest(
 	password = new QLineEdit( vbox );
 	password->setEchoMode( QLineEdit::Password );
 	password->setFocus();
+	savePassword = new QCheckBox( tr("Save password"), vbox );
 	QHBoxLayout *buttonBox;
 	buttonBox = new QHBoxLayout( vboxl, 6 );
 	okPushButton = new QPushButton( this, tr("ok button") );
@@ -47,7 +48,7 @@ KSipAuthenticationRequest::KSipAuthenticationRequest(
 	cancelPushButton->setText( tr("Cancel") );
 	cancelPushButton->setAccel( Key_Escape );
 	buttonBox->addWidget( cancelPushButton );
-	connect( okPushButton, SIGNAL( clicked() ), this, SLOT( accept() ) );
+	connect( okPushButton, SIGNAL( clicked() ), this, SLOT( okClicked() ) );
 	connect( cancelPushButton, SIGNAL( clicked() ), this, SLOT( reject() ) );
 }
 
@@ -75,6 +76,13 @@ QString KSipAuthenticationRequest::getPassword( void )
 	return password->text();
 }
 
+void KSipAuthenticationRequest::okClicked( void )
+{
+	if (savePassword->isChecked())
+		QSettings().writeEntry("/kphone/Registration/Password", getPassword());
+	accept();
+}
+
 KSipAuthentication::KSipAuthentication()
 {
 	authreq = 0;
