@@ -22,7 +22,11 @@ public:
 	QString getUsername( void );
 	QString getPassword( void );
 
+private slots:
+	void okClicked( void );
+
 private:
+	QCheckBox *savePassword;
 	QLineEdit *username;
 	QLineEdit *password;
 	QPushButton *okPushButton;
