@@ -75,20 +75,22 @@ KSipIdentityEdit::~KSipIdentityEdit( void )
 {
 }
 
-void KSipIdentityEdit::updateState( QString state )
+void KSipIdentityEdit::updateState( KsipState state )
 {
-	if( state == "off" ) {
-		buttonRegister->setText( tr("Register") );
+	if( state == OFFLINE ) {
+		buttonRegister->setText( tr("Register : not registered") );
 		buttonRegister->setEnabled( false );
-	} else if( state == "Active" ) {
-		labelRegister->setText( tr("Registration : ") + state );
+	} else if( state == REG ) {
+		labelRegister->setText( tr("Registration : registered"));
 		buttonRegister->setText( tr("Unregister") );
 		buttonRegister->setEnabled( true );
-	} else {
-		labelRegister->setText( tr("Registration : ") + state );
+	} else if ( state == UNREG ) {
+		labelRegister->setText( tr("Registration : not registered"));
 		buttonRegister->setText( tr("Register") );
 		buttonRegister->setEnabled( true );
-	}
+	} else {
+          labelRegister->setText( tr("Registration : ") );
+        }
 }
 
 QString KSipIdentityEdit::getFullname( void ) const
@@ -236,6 +238,8 @@ KSipRegistrations::KSipRegistrations(
 		c->updateIdentity( u, sipreg->getOutboundProxy() );
 		str = settings.readEntry( pp + "/UserName" );
 		u->getMyUri()->setProxyUsername( str );
+		str = settings.readEntry( pp + "/Password" );
+		u->getMyUri()->setPassword( str );
 		str = settings.readEntry( pp + "/AutoRegister" );
 		if( str == "Yes" ) {
 			autoRegister = true;
@@ -278,7 +282,7 @@ void KSipRegistrations::editRegistration( void )
 		edit->setAutoRegister( autoRegister );
 		edit->setQvalue( sipreg->getQvalue() );
 	} else {
-		edit->updateState(tr("off"));
+		edit->updateState( OFFLINE );
 		edit->setFullname( "" );
 		edit->setUsername( "" );
 		edit->setHostname( "" );
@@ -378,24 +382,24 @@ void KSipRegistrations::setRegisterState( void )
 {
 	switch( sipreg->getRegisterState() ) {
 		case SipRegister::NotConnected:
-			edit->updateState( tr("Inactive") );
+			edit->updateState(  UNREG );
 			break;
 		case SipRegister::TryingServer:
 		case SipRegister::TryingServerWithPassword:
-			edit->updateState( tr("Trying...") );
+			edit->updateState( PROC_TRY );
 			break;
 		case SipRegister::AuthenticationRequired:
 		case SipRegister::AuthenticationRequiredWithNewPassword:
-			edit->updateState( tr("Auth Required...") );
+			edit->updateState( AUTHREQ );
 			break;
 		case SipRegister::Connected:
-			edit->updateState( tr("Active") );
+			edit->updateState( REG );
 			break;
 		case SipRegister::Disconnecting:
-			edit->updateState( tr("Unregistering...") );
+			edit->updateState( PROC_UNREG );
 			break;
 		case SipRegister::Reconnecting:
-			edit->updateState( tr("Reregistering...") );
+			edit->updateState( PROC_REG );
 			break;
 	}
 }
