@@ -780,6 +780,10 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
         <source>Register</source>
         <translation>Anmelden</translation>
     </message>
+    <message>
+        <source>Unregister</source>
+        <translation>Abmeldung</translation>
+    </message>
     <message>
         <source>help button</source>
         <translation>Hilfe Knopf</translation>
@@ -805,16 +809,12 @@ Sie einfach und wählen Sie die Funktion, die Sie gerne verwenden möchten.
         <translation>Abbruch</translation>
     </message>
     <message>
-        <source>Active</source>
-        <translation>Aktiv</translation>
+        <source>Registration : not registered</source>
+        <translation>Registrierung : nicht registriert</translation>
     </message>
     <message>
-        <source>Registration : </source>
-        <translation>Registrierung:</translation>
-    </message>
-    <message>
-        <source>Unregister</source>
-        <translation>Abmelden</translation>
+        <source>Registration : registered</source>
+        <translation>Registrierung : registriert</translation>
     </message>
 </context>
 <context>
